# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class SwapOptionV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _invalid_swap_outs: Optional[List[InvalidSwapOutV1]]
    _items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]]
    _swap_root_candidate: Optional[ItemPreviewWithAssetsV1]


    def __init__(
        self,
        invalid_swap_outs: Optional[List[InvalidSwapOutV1]] = None,
        items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]] = None,
        swap_root_candidate: Optional[ItemPreviewWithAssetsV1] = None,
    ) -> None: ...

    @property
    def invalid_swap_outs(self) -> Optional[List[InvalidSwapOutV1]]: ...

    @invalid_swap_outs.setter
    def invalid_swap_outs(self, invalid_swap_outs: Optional[List[InvalidSwapOutV1]]) -> None: ...

    @property
    def items_with_swap_pairs(self) -> Optional[List[ItemWithSwapPairsV1]]: ...

    @items_with_swap_pairs.setter
    def items_with_swap_pairs(self, items_with_swap_pairs: Optional[List[ItemWithSwapPairsV1]]) -> None: ...

    @property
    def swap_root_candidate(self) -> Optional[ItemPreviewWithAssetsV1]: ...

    @swap_root_candidate.setter
    def swap_root_candidate(self, swap_root_candidate: Optional[ItemPreviewWithAssetsV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
