# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AllContextOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _comments: List[ContextCommentOutputV1]
    _labels: List[ContextLabelOutputV1]
    _numerics: List[ContextNumericOutputV1]
    _opaque: List[ContextOpaqueOutputV1]


    def __init__(
        self,
        comments: Optional[List[ContextCommentOutputV1]] = None,
        labels: Optional[List[ContextLabelOutputV1]] = None,
        numerics: Optional[List[ContextNumericOutputV1]] = None,
        opaque: Optional[List[ContextOpaqueOutputV1]] = None,
    ) -> None: ...

    @property
    def comments(self) -> List[ContextCommentOutputV1]: ...

    @comments.setter
    def comments(self, comments: List[ContextCommentOutputV1]) -> None: ...

    @property
    def labels(self) -> List[ContextLabelOutputV1]: ...

    @labels.setter
    def labels(self, labels: List[ContextLabelOutputV1]) -> None: ...

    @property
    def numerics(self) -> List[ContextNumericOutputV1]: ...

    @numerics.setter
    def numerics(self, numerics: List[ContextNumericOutputV1]) -> None: ...

    @property
    def opaque(self) -> List[ContextOpaqueOutputV1]: ...

    @opaque.setter
    def opaque(self, opaque: List[ContextOpaqueOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
