# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class ConditionMonitorsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def archive_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ArchiveOutputV1: ...

    def archive_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def create_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def get_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor_metadata_list(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorMetadataOutputListV1: ...

    def get_condition_monitor_metadata_list_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitor_suppressions(
        self,
        **kwargs: Any,
    ) -> List[SuppressedConditionOutputV1]: ...

    def get_condition_monitor_suppressions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_condition_monitors(
        self,
        **kwargs: Any,
    ) -> GetConditionMonitorItemsOutputV1: ...

    def get_condition_monitors_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_monitored_conditions(
        self,
        **kwargs: Any,
    ) -> MonitoredConditionOutputListV1: ...

    def get_monitored_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def run_condition_monitor_job(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def run_condition_monitor_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def suppress_conditions(
        self,
        **kwargs: Any,
    ) -> None: ...

    def suppress_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def unsuppress_conditions(
        self,
        **kwargs: Any,
    ) -> None: ...

    def unsuppress_conditions_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def update_condition_monitor(
        self,
        **kwargs: Any,
    ) -> ConditionMonitorOutputV1: ...

    def update_condition_monitor_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
