# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class BoardTimeframeComparisonMetricOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _baseline_value: Optional[float]
    _column: str
    _current_value: Optional[float]
    _delta: Optional[float]
    _metric: str
    _percent_change: Optional[float]


    def __init__(
        self,
        baseline_value: Optional[float] = None,
        column: Optional[str] = None,
        current_value: Optional[float] = None,
        delta: Optional[float] = None,
        metric: Optional[str] = None,
        percent_change: Optional[float] = None,
    ) -> None: ...

    @property
    def baseline_value(self) -> Optional[float]: ...

    @baseline_value.setter
    def baseline_value(self, baseline_value: Optional[float]) -> None: ...

    @property
    def column(self) -> str: ...

    @column.setter
    def column(self, column: str) -> None: ...

    @property
    def current_value(self) -> Optional[float]: ...

    @current_value.setter
    def current_value(self, current_value: Optional[float]) -> None: ...

    @property
    def delta(self) -> Optional[float]: ...

    @delta.setter
    def delta(self, delta: Optional[float]) -> None: ...

    @property
    def metric(self) -> str: ...

    @metric.setter
    def metric(self, metric: str) -> None: ...

    @property
    def percent_change(self) -> Optional[float]: ...

    @percent_change.setter
    def percent_change(self, percent_change: Optional[float]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
