# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class InstanceOutputMappingV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'boolean_output': 'bool',
        'feature_id': 'str',
        'is_archived': 'bool',
        'output_id': 'str',
        'output_id_inactive': 'bool'
    }

    attribute_map = {
        'boolean_output': 'booleanOutput',
        'feature_id': 'featureId',
        'is_archived': 'isArchived',
        'output_id': 'outputId',
        'output_id_inactive': 'outputIdInactive'
    }

    def __init__(self, boolean_output=None, feature_id=None, is_archived=None, output_id=None, output_id_inactive=None):
        """
        InstanceOutputMappingV1 - a model defined in Swagger
        """

        self._boolean_output = None
        self._feature_id = None
        self._is_archived = None
        self._output_id = None
        self._output_id_inactive = None

        if boolean_output is not None:
          self.boolean_output = boolean_output
        if feature_id is not None:
          self.feature_id = feature_id
        if is_archived is not None:
          self.is_archived = is_archived
        if output_id is not None:
          self.output_id = output_id
        if output_id_inactive is not None:
          self.output_id_inactive = output_id_inactive

    @property
    def boolean_output(self):
        """
        Gets the boolean_output of this InstanceOutputMappingV1.
        Boolean literal output, if applicable

        :return: The boolean_output of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._boolean_output

    @boolean_output.setter
    def boolean_output(self, boolean_output):
        """
        Sets the boolean_output of this InstanceOutputMappingV1.
        Boolean literal output, if applicable

        :param boolean_output: The boolean_output of this InstanceOutputMappingV1.
        :type: bool
        """

        self._boolean_output = boolean_output

    @property
    def feature_id(self):
        """
        Gets the feature_id of this InstanceOutputMappingV1.
        Feature ID

        :return: The feature_id of this InstanceOutputMappingV1.
        :rtype: str
        """
        return self._feature_id

    @feature_id.setter
    def feature_id(self, feature_id):
        """
        Sets the feature_id of this InstanceOutputMappingV1.
        Feature ID

        :param feature_id: The feature_id of this InstanceOutputMappingV1.
        :type: str
        """

        self._feature_id = feature_id

    @property
    def is_archived(self):
        """
        Gets the is_archived of this InstanceOutputMappingV1.

        :return: The is_archived of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._is_archived

    @is_archived.setter
    def is_archived(self, is_archived):
        """
        Sets the is_archived of this InstanceOutputMappingV1.

        :param is_archived: The is_archived of this InstanceOutputMappingV1.
        :type: bool
        """

        self._is_archived = is_archived

    @property
    def output_id(self):
        """
        Gets the output_id of this InstanceOutputMappingV1.
        ID of the Item created by the associated Feature, if applicable

        :return: The output_id of this InstanceOutputMappingV1.
        :rtype: str
        """
        return self._output_id

    @output_id.setter
    def output_id(self, output_id):
        """
        Sets the output_id of this InstanceOutputMappingV1.
        ID of the Item created by the associated Feature, if applicable

        :param output_id: The output_id of this InstanceOutputMappingV1.
        :type: str
        """

        self._output_id = output_id

    @property
    def output_id_inactive(self):
        """
        Gets the output_id_inactive of this InstanceOutputMappingV1.
        Whether the outputId has been overwritten by a null value. If true, the outputId is for information purposes only, and the current value is null.

        :return: The output_id_inactive of this InstanceOutputMappingV1.
        :rtype: bool
        """
        return self._output_id_inactive

    @output_id_inactive.setter
    def output_id_inactive(self, output_id_inactive):
        """
        Sets the output_id_inactive of this InstanceOutputMappingV1.
        Whether the outputId has been overwritten by a null value. If true, the outputId is for information purposes only, and the current value is null.

        :param output_id_inactive: The output_id_inactive of this InstanceOutputMappingV1.
        :type: bool
        """

        self._output_id_inactive = output_id_inactive

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, InstanceOutputMappingV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
