# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class BoardFilterCreateInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'board_id': 'str',
        'config': 'str',
        'display_type': 'str'
    }

    attribute_map = {
        'board_id': 'boardId',
        'config': 'config',
        'display_type': 'displayType'
    }

    def __init__(self, board_id=None, config=None, display_type=None):
        """
        BoardFilterCreateInputV1 - a model defined in Swagger
        """

        self._board_id = None
        self._config = None
        self._display_type = None

        if board_id is not None:
          self.board_id = board_id
        if config is not None:
          self.config = config
        if display_type is not None:
          self.display_type = display_type

    @property
    def board_id(self):
        """
        Gets the board_id of this BoardFilterCreateInputV1.
        Identifier of the board this filter belongs to

        :return: The board_id of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._board_id

    @board_id.setter
    def board_id(self, board_id):
        """
        Sets the board_id of this BoardFilterCreateInputV1.
        Identifier of the board this filter belongs to

        :param board_id: The board_id of this BoardFilterCreateInputV1.
        :type: str
        """
        if board_id is None:
            raise ValueError("Invalid value for `board_id`, must not be `None`")

        self._board_id = board_id

    @property
    def config(self):
        """
        Gets the config of this BoardFilterCreateInputV1.
        Configuration JSON for the filter

        :return: The config of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._config

    @config.setter
    def config(self, config):
        """
        Sets the config of this BoardFilterCreateInputV1.
        Configuration JSON for the filter

        :param config: The config of this BoardFilterCreateInputV1.
        :type: str
        """

        self._config = config

    @property
    def display_type(self):
        """
        Gets the display_type of this BoardFilterCreateInputV1.
        The display type for the filter (e.g., select)

        :return: The display_type of this BoardFilterCreateInputV1.
        :rtype: str
        """
        return self._display_type

    @display_type.setter
    def display_type(self, display_type):
        """
        Sets the display_type of this BoardFilterCreateInputV1.
        The display type for the filter (e.g., select)

        :param display_type: The display_type of this BoardFilterCreateInputV1.
        :type: str
        """

        self._display_type = display_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, BoardFilterCreateInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
