# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class WorksheetInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _branch_from: Optional[str]
    _clone_name_prefix: Optional[str]
    _clone_name_suffix: Optional[str]
    _item_ids_to_clone: Optional[List[str]]
    _name: str


    def __init__(
        self,
        branch_from: Optional[str] = None,
        clone_name_prefix: Optional[str] = None,
        clone_name_suffix: Optional[str] = None,
        item_ids_to_clone: Optional[List[str]] = None,
        name: Optional[str] = None,
    ) -> None: ...

    @property
    def branch_from(self) -> Optional[str]: ...

    @branch_from.setter
    def branch_from(self, branch_from: Optional[str]) -> None: ...

    @property
    def clone_name_prefix(self) -> Optional[str]: ...

    @clone_name_prefix.setter
    def clone_name_prefix(self, clone_name_prefix: Optional[str]) -> None: ...

    @property
    def clone_name_suffix(self) -> Optional[str]: ...

    @clone_name_suffix.setter
    def clone_name_suffix(self, clone_name_suffix: Optional[str]) -> None: ...

    @property
    def item_ids_to_clone(self) -> Optional[List[str]]: ...

    @item_ids_to_clone.setter
    def item_ids_to_clone(self, item_ids_to_clone: Optional[List[str]]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
