# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ModelApplicationErrorOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _feature_id: Optional[str]
    _message: Optional[str]
    _message_arguments: Optional[Dict[str, str]]
    _message_number: Optional[int]
    _model_id: Optional[str]
    _rule_id: Optional[str]


    def __init__(
        self,
        feature_id: Optional[str] = None,
        message: Optional[str] = None,
        message_arguments: Optional[Dict[str, str]] = None,
        message_number: Optional[int] = None,
        model_id: Optional[str] = None,
        rule_id: Optional[str] = None,
    ) -> None: ...

    @property
    def feature_id(self) -> Optional[str]: ...

    @feature_id.setter
    def feature_id(self, feature_id: Optional[str]) -> None: ...

    @property
    def message(self) -> Optional[str]: ...

    @message.setter
    def message(self, message: Optional[str]) -> None: ...

    @property
    def message_arguments(self) -> Optional[Dict[str, str]]: ...

    @message_arguments.setter
    def message_arguments(self, message_arguments: Optional[Dict[str, str]]) -> None: ...

    @property
    def message_number(self) -> Optional[int]: ...

    @message_number.setter
    def message_number(self, message_number: Optional[int]) -> None: ...

    @property
    def model_id(self) -> Optional[str]: ...

    @model_id.setter
    def model_id(self, model_id: Optional[str]) -> None: ...

    @property
    def rule_id(self) -> Optional[str]: ...

    @rule_id.setter
    def rule_id(self, rule_id: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
