# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, Dict, List, Optional, Set

from ..api_client import ApiClient
from ..configuration import Configuration
from ..models import *

class JobsApi(object):
    api_client: ApiClient

    def __init__(self, api_client: Optional[ApiClient] = None) -> None: ...

    def create_content_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def create_content_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def create_date_range_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def create_date_range_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def delete_job(
        self,
        **kwargs: Any,
    ) -> StatusMessageBase: ...

    def delete_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_job(
        self,
        **kwargs: Any,
    ) -> JobOutputV1: ...

    def get_job_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_jobs(
        self,
        **kwargs: Any,
    ) -> GetJobsOutputV1: ...

    def get_jobs_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def get_screenshot_from_content(
        self,
        **kwargs: Any,
    ) -> ScreenshotOutputV1: ...

    def get_screenshot_from_content_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...

    def validate_cron(
        self,
        **kwargs: Any,
    ) -> ValidateCronListOutputV1: ...

    def validate_cron_with_http_info(
        self,
        **kwargs: Any,
    ) -> Any: ...
