# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class LogMessage(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'exception': 'str',
        'failure_reasons': 'list[str]',
        'formatted_level': 'str',
        'level': 'str',
        'logger_name': 'str',
        'message': 'str',
        'source': 'str',
        'time': 'str',
        'valid': 'bool'
    }

    attribute_map = {
        'exception': 'exception',
        'failure_reasons': 'failureReasons',
        'formatted_level': 'formattedLevel',
        'level': 'level',
        'logger_name': 'loggerName',
        'message': 'message',
        'source': 'source',
        'time': 'time',
        'valid': 'valid'
    }

    def __init__(self, exception=None, failure_reasons=None, formatted_level=None, level=None, logger_name=None, message=None, source=None, time=None, valid=None):
        """
        LogMessage - a model defined in Swagger
        """

        self._exception = None
        self._failure_reasons = None
        self._formatted_level = None
        self._level = None
        self._logger_name = None
        self._message = None
        self._source = None
        self._time = None
        self._valid = None

        if exception is not None:
          self.exception = exception
        if failure_reasons is not None:
          self.failure_reasons = failure_reasons
        if formatted_level is not None:
          self.formatted_level = formatted_level
        if level is not None:
          self.level = level
        if logger_name is not None:
          self.logger_name = logger_name
        if message is not None:
          self.message = message
        if source is not None:
          self.source = source
        if time is not None:
          self.time = time
        if valid is not None:
          self.valid = valid

    @property
    def exception(self):
        """
        Gets the exception of this LogMessage.
        Exception message if any

        :return: The exception of this LogMessage.
        :rtype: str
        """
        return self._exception

    @exception.setter
    def exception(self, exception):
        """
        Sets the exception of this LogMessage.
        Exception message if any

        :param exception: The exception of this LogMessage.
        :type: str
        """

        self._exception = exception

    @property
    def failure_reasons(self):
        """
        Gets the failure_reasons of this LogMessage.

        :return: The failure_reasons of this LogMessage.
        :rtype: list[str]
        """
        return self._failure_reasons

    @failure_reasons.setter
    def failure_reasons(self, failure_reasons):
        """
        Sets the failure_reasons of this LogMessage.

        :param failure_reasons: The failure_reasons of this LogMessage.
        :type: list[str]
        """

        self._failure_reasons = failure_reasons

    @property
    def formatted_level(self):
        """
        Gets the formatted_level of this LogMessage.

        :return: The formatted_level of this LogMessage.
        :rtype: str
        """
        return self._formatted_level

    @formatted_level.setter
    def formatted_level(self, formatted_level):
        """
        Sets the formatted_level of this LogMessage.

        :param formatted_level: The formatted_level of this LogMessage.
        :type: str
        """

        self._formatted_level = formatted_level

    @property
    def level(self):
        """
        Gets the level of this LogMessage.
        Log level: TRACE, DEBUG, INFO, WARN, ERROR

        :return: The level of this LogMessage.
        :rtype: str
        """
        return self._level

    @level.setter
    def level(self, level):
        """
        Sets the level of this LogMessage.
        Log level: TRACE, DEBUG, INFO, WARN, ERROR

        :param level: The level of this LogMessage.
        :type: str
        """
        if level is None:
            raise ValueError("Invalid value for `level`, must not be `None`")

        self._level = level

    @property
    def logger_name(self):
        """
        Gets the logger_name of this LogMessage.
        Logger name

        :return: The logger_name of this LogMessage.
        :rtype: str
        """
        return self._logger_name

    @logger_name.setter
    def logger_name(self, logger_name):
        """
        Sets the logger_name of this LogMessage.
        Logger name

        :param logger_name: The logger_name of this LogMessage.
        :type: str
        """

        self._logger_name = logger_name

    @property
    def message(self):
        """
        Gets the message of this LogMessage.
        Log message

        :return: The message of this LogMessage.
        :rtype: str
        """
        return self._message

    @message.setter
    def message(self, message):
        """
        Sets the message of this LogMessage.
        Log message

        :param message: The message of this LogMessage.
        :type: str
        """
        if message is None:
            raise ValueError("Invalid value for `message`, must not be `None`")

        self._message = message

    @property
    def source(self):
        """
        Gets the source of this LogMessage.
        Thread name

        :return: The source of this LogMessage.
        :rtype: str
        """
        return self._source

    @source.setter
    def source(self, source):
        """
        Sets the source of this LogMessage.
        Thread name

        :param source: The source of this LogMessage.
        :type: str
        """
        if source is None:
            raise ValueError("Invalid value for `source`, must not be `None`")

        self._source = source

    @property
    def time(self):
        """
        Gets the time of this LogMessage.
        Timestamp for the log message in ISO-8601 format

        :return: The time of this LogMessage.
        :rtype: str
        """
        return self._time

    @time.setter
    def time(self, time):
        """
        Sets the time of this LogMessage.
        Timestamp for the log message in ISO-8601 format

        :param time: The time of this LogMessage.
        :type: str
        """
        if time is None:
            raise ValueError("Invalid value for `time`, must not be `None`")

        self._time = time

    @property
    def valid(self):
        """
        Gets the valid of this LogMessage.

        :return: The valid of this LogMessage.
        :rtype: bool
        """
        return self._valid

    @valid.setter
    def valid(self, valid):
        """
        Sets the valid of this LogMessage.

        :param valid: The valid of this LogMessage.
        :type: bool
        """

        self._valid = valid

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, LogMessage):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
