# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ColumnRuleEventAssetCreatorInputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'description': 'str',
        'identity_id': 'str',
        'permission_string': 'str',
        'property_name': 'str'
    }

    attribute_map = {
        'description': 'description',
        'identity_id': 'identityId',
        'permission_string': 'permissionString',
        'property_name': 'propertyName'
    }

    def __init__(self, description=None, identity_id=None, permission_string=None, property_name=None):
        """
        ColumnRuleEventAssetCreatorInputV1 - a model defined in Swagger
        """

        self._description = None
        self._identity_id = None
        self._permission_string = None
        self._property_name = None

        if description is not None:
          self.description = description
        if identity_id is not None:
          self.identity_id = identity_id
        if permission_string is not None:
          self.permission_string = permission_string
        if property_name is not None:
          self.property_name = property_name

    @property
    def description(self):
        """
        Gets the description of this ColumnRuleEventAssetCreatorInputV1.
        Clarifying information or other plain language description for assets created by this rule. An input of just whitespace is equivalent to a null input.

        :return: The description of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ColumnRuleEventAssetCreatorInputV1.
        Clarifying information or other plain language description for assets created by this rule. An input of just whitespace is equivalent to a null input.

        :param description: The description of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._description = description

    @property
    def identity_id(self):
        """
        Gets the identity_id of this ColumnRuleEventAssetCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :return: The identity_id of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._identity_id

    @identity_id.setter
    def identity_id(self, identity_id):
        """
        Sets the identity_id of this ColumnRuleEventAssetCreatorInputV1.
        The ID of the identity for which permissions will be set on items created by this rule. A null value means that the items created by this rule will have the same permissions as its associated datasource. Must be set along with permissionString.

        :param identity_id: The identity_id of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._identity_id = identity_id

    @property
    def permission_string(self):
        """
        Gets the permission_string of this ColumnRuleEventAssetCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :return: The permission_string of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._permission_string

    @permission_string.setter
    def permission_string(self, permission_string):
        """
        Sets the permission_string of this ColumnRuleEventAssetCreatorInputV1.
        The permissions for the identity included for items created by this rule. Must be in a valid string form with each permission separated by a comma, for example 'r,w,m'. Acceptable permissions are: 'r' - read, 'w' - write, 'm' - manage.Must be set along with identityId.

        :param permission_string: The permission_string of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """

        self._permission_string = permission_string

    @property
    def property_name(self):
        """
        Gets the property_name of this ColumnRuleEventAssetCreatorInputV1.
        The property to choose from an event to select a Hierarchy Node. The property name can include dot notation to specify ancestor or child items. Supported: children[<child name>] for children, parent[<level>] or ancestor[<level] for an ancestor at a specific level, or parent[<level>].children[<child name>] or ancestor[<level>].children[<child name>] for a child of an ancestor at a specific level.

        :return: The property_name of this ColumnRuleEventAssetCreatorInputV1.
        :rtype: str
        """
        return self._property_name

    @property_name.setter
    def property_name(self, property_name):
        """
        Sets the property_name of this ColumnRuleEventAssetCreatorInputV1.
        The property to choose from an event to select a Hierarchy Node. The property name can include dot notation to specify ancestor or child items. Supported: children[<child name>] for children, parent[<level>] or ancestor[<level] for an ancestor at a specific level, or parent[<level>].children[<child name>] or ancestor[<level>].children[<child name>] for a child of an ancestor at a specific level.

        :param property_name: The property_name of this ColumnRuleEventAssetCreatorInputV1.
        :type: str
        """
        if property_name is None:
            raise ValueError("Invalid value for `property_name`, must not be `None`")

        self._property_name = property_name

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ColumnRuleEventAssetCreatorInputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
