# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class TableJoinInput(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'column_ids_to_include': 'list[str]',
        'column_to_join': 'str',
        'table_definition_id': 'str'
    }

    attribute_map = {
        'column_ids_to_include': 'columnIdsToInclude',
        'column_to_join': 'columnToJoin',
        'table_definition_id': 'tableDefinitionId'
    }

    def __init__(self, column_ids_to_include=None, column_to_join=None, table_definition_id=None):
        """
        TableJoinInput - a model defined in Swagger
        """

        self._column_ids_to_include = None
        self._column_to_join = None
        self._table_definition_id = None

        if column_ids_to_include is not None:
          self.column_ids_to_include = column_ids_to_include
        if column_to_join is not None:
          self.column_to_join = column_to_join
        if table_definition_id is not None:
          self.table_definition_id = table_definition_id

    @property
    def column_ids_to_include(self):
        """
        Gets the column_ids_to_include of this TableJoinInput.
        Column IDs to include from the joined table. Leave empty to include all columns from the join table.

        :return: The column_ids_to_include of this TableJoinInput.
        :rtype: list[str]
        """
        return self._column_ids_to_include

    @column_ids_to_include.setter
    def column_ids_to_include(self, column_ids_to_include):
        """
        Sets the column_ids_to_include of this TableJoinInput.
        Column IDs to include from the joined table. Leave empty to include all columns from the join table.

        :param column_ids_to_include: The column_ids_to_include of this TableJoinInput.
        :type: list[str]
        """

        self._column_ids_to_include = column_ids_to_include

    @property
    def column_to_join(self):
        """
        Gets the column_to_join of this TableJoinInput.
        Optional UUID column ID within the joined table to use as the join key. Must be indexed

        :return: The column_to_join of this TableJoinInput.
        :rtype: str
        """
        return self._column_to_join

    @column_to_join.setter
    def column_to_join(self, column_to_join):
        """
        Sets the column_to_join of this TableJoinInput.
        Optional UUID column ID within the joined table to use as the join key. Must be indexed

        :param column_to_join: The column_to_join of this TableJoinInput.
        :type: str
        """

        self._column_to_join = column_to_join

    @property
    def table_definition_id(self):
        """
        Gets the table_definition_id of this TableJoinInput.
        ID of the table definition to join against

        :return: The table_definition_id of this TableJoinInput.
        :rtype: str
        """
        return self._table_definition_id

    @table_definition_id.setter
    def table_definition_id(self, table_definition_id):
        """
        Sets the table_definition_id of this TableJoinInput.
        ID of the table definition to join against

        :param table_definition_id: The table_definition_id of this TableJoinInput.
        :type: str
        """

        self._table_definition_id = table_definition_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TableJoinInput):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
