# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class CapsulesOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _capsules: List[CapsuleV1]
    _continuation_token: Optional[str]
    _key_unit_of_measure: Optional[str]
    _limit: Optional[int]
    _next: Optional[str]
    _status_message: Optional[str]
    _warning_count: Optional[int]
    _warning_logs: Optional[List[FormulaLogV1]]


    def __init__(
        self,
        capsules: Optional[List[CapsuleV1]] = None,
        continuation_token: Optional[str] = None,
        key_unit_of_measure: Optional[str] = None,
        limit: Optional[int] = None,
        next: Optional[str] = None,
        status_message: Optional[str] = None,
        warning_count: Optional[int] = None,
        warning_logs: Optional[List[FormulaLogV1]] = None,
    ) -> None: ...

    @property
    def capsules(self) -> List[CapsuleV1]: ...

    @capsules.setter
    def capsules(self, capsules: List[CapsuleV1]) -> None: ...

    @property
    def continuation_token(self) -> Optional[str]: ...

    @continuation_token.setter
    def continuation_token(self, continuation_token: Optional[str]) -> None: ...

    @property
    def key_unit_of_measure(self) -> Optional[str]: ...

    @key_unit_of_measure.setter
    def key_unit_of_measure(self, key_unit_of_measure: Optional[str]) -> None: ...

    @property
    def limit(self) -> Optional[int]: ...

    @limit.setter
    def limit(self, limit: Optional[int]) -> None: ...

    @property
    def next(self) -> Optional[str]: ...

    @next.setter
    def next(self, next: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def warning_count(self) -> Optional[int]: ...

    @warning_count.setter
    def warning_count(self, warning_count: Optional[int]) -> None: ...

    @property
    def warning_logs(self) -> Optional[List[FormulaLogV1]]: ...

    @warning_logs.setter
    def warning_logs(self, warning_logs: Optional[List[FormulaLogV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
