# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class ChannelOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _created_at: Optional[str]
    _id: Optional[str]
    _last_published_at: Optional[str]
    _published_count: Optional[int]
    _subscriptions: Optional[List[SubscriptionOutputV1]]
    _type: Optional[str]


    def __init__(
        self,
        created_at: Optional[str] = None,
        id: Optional[str] = None,
        last_published_at: Optional[str] = None,
        published_count: Optional[int] = None,
        subscriptions: Optional[List[SubscriptionOutputV1]] = None,
        type: Optional[str] = None,
    ) -> None: ...

    @property
    def created_at(self) -> Optional[str]: ...

    @created_at.setter
    def created_at(self, created_at: Optional[str]) -> None: ...

    @property
    def id(self) -> Optional[str]: ...

    @id.setter
    def id(self, id: Optional[str]) -> None: ...

    @property
    def last_published_at(self) -> Optional[str]: ...

    @last_published_at.setter
    def last_published_at(self, last_published_at: Optional[str]) -> None: ...

    @property
    def published_count(self) -> Optional[int]: ...

    @published_count.setter
    def published_count(self, published_count: Optional[int]) -> None: ...

    @property
    def subscriptions(self) -> Optional[List[SubscriptionOutputV1]]: ...

    @subscriptions.setter
    def subscriptions(self, subscriptions: Optional[List[SubscriptionOutputV1]]) -> None: ...

    @property
    def type(self) -> Optional[str]: ...

    @type.setter
    def type(self, type: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
