# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class JiraAttachment(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _content: Optional[Any]
    _filename: Optional[str]
    _media_type: Optional[MediaType]


    def __init__(
        self,
        content: Optional[Any] = None,
        filename: Optional[str] = None,
        media_type: Optional[MediaType] = None,
    ) -> None: ...

    @property
    def content(self) -> Optional[Any]: ...

    @content.setter
    def content(self, content: Optional[Any]) -> None: ...

    @property
    def filename(self) -> Optional[str]: ...

    @filename.setter
    def filename(self, filename: Optional[str]) -> None: ...

    @property
    def media_type(self) -> Optional[MediaType]: ...

    @media_type.setter
    def media_type(self, media_type: Optional[MediaType]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
