# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ItemFinderSearchesOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'has_more': 'bool',
        'items': 'list[ItemPreviewV1]',
        'warnings': 'list[str]'
    }

    attribute_map = {
        'has_more': 'hasMore',
        'items': 'items',
        'warnings': 'warnings'
    }

    def __init__(self, has_more=None, items=None, warnings=None):
        """
        ItemFinderSearchesOutputV1 - a model defined in Swagger
        """

        self._has_more = None
        self._items = None
        self._warnings = None

        if has_more is not None:
          self.has_more = has_more
        if items is not None:
          self.items = items
        if warnings is not None:
          self.warnings = warnings

    @property
    def has_more(self):
        """
        Gets the has_more of this ItemFinderSearchesOutputV1.
        True if there are more items found by the match that were not returned

        :return: The has_more of this ItemFinderSearchesOutputV1.
        :rtype: bool
        """
        return self._has_more

    @has_more.setter
    def has_more(self, has_more):
        """
        Sets the has_more of this ItemFinderSearchesOutputV1.
        True if there are more items found by the match that were not returned

        :param has_more: The has_more of this ItemFinderSearchesOutputV1.
        :type: bool
        """
        if has_more is None:
            raise ValueError("Invalid value for `has_more`, must not be `None`")

        self._has_more = has_more

    @property
    def items(self):
        """
        Gets the items of this ItemFinderSearchesOutputV1.
        The items found

        :return: The items of this ItemFinderSearchesOutputV1.
        :rtype: list[ItemPreviewV1]
        """
        return self._items

    @items.setter
    def items(self, items):
        """
        Sets the items of this ItemFinderSearchesOutputV1.
        The items found

        :param items: The items of this ItemFinderSearchesOutputV1.
        :type: list[ItemPreviewV1]
        """
        if items is None:
            raise ValueError("Invalid value for `items`, must not be `None`")

        self._items = items

    @property
    def warnings(self):
        """
        Gets the warnings of this ItemFinderSearchesOutputV1.
        Warnings from search execution

        :return: The warnings of this ItemFinderSearchesOutputV1.
        :rtype: list[str]
        """
        return self._warnings

    @warnings.setter
    def warnings(self, warnings):
        """
        Sets the warnings of this ItemFinderSearchesOutputV1.
        Warnings from search execution

        :param warnings: The warnings of this ItemFinderSearchesOutputV1.
        :type: list[str]
        """
        if warnings is None:
            raise ValueError("Invalid value for `warnings`, must not be `None`")

        self._warnings = warnings

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ItemFinderSearchesOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
