# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TableDefinitionPreviewOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _column_definitions: List[ColumnDefinitionOutputV1]
    _compute_results: Dict[str, List[RowRulesResultV1]]
    _table: MaterializedTableV1


    def __init__(
        self,
        column_definitions: Optional[List[ColumnDefinitionOutputV1]] = None,
        compute_results: Optional[Dict[str, List[RowRulesResultV1]]] = None,
        table: Optional[MaterializedTableV1] = None,
    ) -> None: ...

    @property
    def column_definitions(self) -> List[ColumnDefinitionOutputV1]: ...

    @column_definitions.setter
    def column_definitions(self, column_definitions: List[ColumnDefinitionOutputV1]) -> None: ...

    @property
    def compute_results(self) -> Dict[str, List[RowRulesResultV1]]: ...

    @compute_results.setter
    def compute_results(self, compute_results: Dict[str, List[RowRulesResultV1]]) -> None: ...

    @property
    def table(self) -> MaterializedTableV1: ...

    @table.setter
    def table(self, table: MaterializedTableV1) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
