# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class TreemapOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _errors: Optional[List[FormulaCompilerErrorOutputV1]]
    _metadata: Optional[Dict[str, str]]
    _parent_asset: Optional[AssetOutputV1]
    _return_type: Optional[str]
    _status_message: Optional[str]
    _tree: Optional[List[TreemapItemOutputV1]]
    _upgrade_details: Optional[FormulaUpgradeOutputV1]
    _warning_count: Optional[int]
    _warning_logs: Optional[List[FormulaLogV1]]


    def __init__(
        self,
        errors: Optional[List[FormulaCompilerErrorOutputV1]] = None,
        metadata: Optional[Dict[str, str]] = None,
        parent_asset: Optional[AssetOutputV1] = None,
        return_type: Optional[str] = None,
        status_message: Optional[str] = None,
        tree: Optional[List[TreemapItemOutputV1]] = None,
        upgrade_details: Optional[FormulaUpgradeOutputV1] = None,
        warning_count: Optional[int] = None,
        warning_logs: Optional[List[FormulaLogV1]] = None,
    ) -> None: ...

    @property
    def errors(self) -> Optional[List[FormulaCompilerErrorOutputV1]]: ...

    @errors.setter
    def errors(self, errors: Optional[List[FormulaCompilerErrorOutputV1]]) -> None: ...

    @property
    def metadata(self) -> Optional[Dict[str, str]]: ...

    @metadata.setter
    def metadata(self, metadata: Optional[Dict[str, str]]) -> None: ...

    @property
    def parent_asset(self) -> Optional[AssetOutputV1]: ...

    @parent_asset.setter
    def parent_asset(self, parent_asset: Optional[AssetOutputV1]) -> None: ...

    @property
    def return_type(self) -> Optional[str]: ...

    @return_type.setter
    def return_type(self, return_type: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def tree(self) -> Optional[List[TreemapItemOutputV1]]: ...

    @tree.setter
    def tree(self, tree: Optional[List[TreemapItemOutputV1]]) -> None: ...

    @property
    def upgrade_details(self) -> Optional[FormulaUpgradeOutputV1]: ...

    @upgrade_details.setter
    def upgrade_details(self, upgrade_details: Optional[FormulaUpgradeOutputV1]) -> None: ...

    @property
    def warning_count(self) -> Optional[int]: ...

    @warning_count.setter
    def warning_count(self, warning_count: Optional[int]) -> None: ...

    @property
    def warning_logs(self) -> Optional[List[FormulaLogV1]]: ...

    @warning_logs.setter
    def warning_logs(self, warning_logs: Optional[List[FormulaLogV1]]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
