# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class MaterializedTableSourceV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]]
    _condition_and_metric_column: str
    _condition_stats: Optional[List[ConditionTableStatInputForTableV1]]
    _table_id: str


    def __init__(
        self,
        additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]] = None,
        condition_and_metric_column: Optional[str] = None,
        condition_stats: Optional[List[ConditionTableStatInputForTableV1]] = None,
        table_id: Optional[str] = None,
    ) -> None: ...

    @property
    def additional_column_properties(self) -> Optional[List[PropertiesForItemUUIDColumnInputV1]]: ...

    @additional_column_properties.setter
    def additional_column_properties(self, additional_column_properties: Optional[List[PropertiesForItemUUIDColumnInputV1]]) -> None: ...

    @property
    def condition_and_metric_column(self) -> str: ...

    @condition_and_metric_column.setter
    def condition_and_metric_column(self, condition_and_metric_column: str) -> None: ...

    @property
    def condition_stats(self) -> Optional[List[ConditionTableStatInputForTableV1]]: ...

    @condition_stats.setter
    def condition_stats(self, condition_stats: Optional[List[ConditionTableStatInputForTableV1]]) -> None: ...

    @property
    def table_id(self) -> str: ...

    @table_id.setter
    def table_id(self, table_id: str) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
