# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from pprint import pformat
from six import iteritems
import re


class ModelVersionOutputV1(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'created_at': 'str',
        'creator_name': 'str',
        'notes': 'str',
        'production': 'bool',
        'version': 'int',
        'version_id': 'str'
    }

    attribute_map = {
        'created_at': 'createdAt',
        'creator_name': 'creatorName',
        'notes': 'notes',
        'production': 'production',
        'version': 'version',
        'version_id': 'versionId'
    }

    def __init__(self, created_at=None, creator_name=None, notes=None, production=None, version=None, version_id=None):
        """
        ModelVersionOutputV1 - a model defined in Swagger
        """

        self._created_at = None
        self._creator_name = None
        self._notes = None
        self._production = None
        self._version = None
        self._version_id = None

        if created_at is not None:
          self.created_at = created_at
        if creator_name is not None:
          self.creator_name = creator_name
        if notes is not None:
          self.notes = notes
        if production is not None:
          self.production = production
        if version is not None:
          self.version = version
        if version_id is not None:
          self.version_id = version_id

    @property
    def created_at(self):
        """
        Gets the created_at of this ModelVersionOutputV1.
        ISO-8601 timestamp indicating when this version was published

        :return: The created_at of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._created_at

    @created_at.setter
    def created_at(self, created_at):
        """
        Sets the created_at of this ModelVersionOutputV1.
        ISO-8601 timestamp indicating when this version was published

        :param created_at: The created_at of this ModelVersionOutputV1.
        :type: str
        """
        if created_at is None:
            raise ValueError("Invalid value for `created_at`, must not be `None`")

        self._created_at = created_at

    @property
    def creator_name(self):
        """
        Gets the creator_name of this ModelVersionOutputV1.
        Display name of the user who published this version

        :return: The creator_name of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._creator_name

    @creator_name.setter
    def creator_name(self, creator_name):
        """
        Sets the creator_name of this ModelVersionOutputV1.
        Display name of the user who published this version

        :param creator_name: The creator_name of this ModelVersionOutputV1.
        :type: str
        """

        self._creator_name = creator_name

    @property
    def notes(self):
        """
        Gets the notes of this ModelVersionOutputV1.
        Notes about this version entered at publish time

        :return: The notes of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._notes

    @notes.setter
    def notes(self, notes):
        """
        Sets the notes of this ModelVersionOutputV1.
        Notes about this version entered at publish time

        :param notes: The notes of this ModelVersionOutputV1.
        :type: str
        """

        self._notes = notes

    @property
    def production(self):
        """
        Gets the production of this ModelVersionOutputV1.
        Whether this version is the current production version

        :return: The production of this ModelVersionOutputV1.
        :rtype: bool
        """
        return self._production

    @production.setter
    def production(self, production):
        """
        Sets the production of this ModelVersionOutputV1.
        Whether this version is the current production version

        :param production: The production of this ModelVersionOutputV1.
        :type: bool
        """
        if production is None:
            raise ValueError("Invalid value for `production`, must not be `None`")

        self._production = production

    @property
    def version(self):
        """
        Gets the version of this ModelVersionOutputV1.
        The version number (1, 2, 3, etc.)

        :return: The version of this ModelVersionOutputV1.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """
        Sets the version of this ModelVersionOutputV1.
        The version number (1, 2, 3, etc.)

        :param version: The version of this ModelVersionOutputV1.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version

    @property
    def version_id(self):
        """
        Gets the version_id of this ModelVersionOutputV1.
        The GUID of the locked Model snapshot for this version

        :return: The version_id of this ModelVersionOutputV1.
        :rtype: str
        """
        return self._version_id

    @version_id.setter
    def version_id(self, version_id):
        """
        Sets the version_id of this ModelVersionOutputV1.
        The GUID of the locked Model snapshot for this version

        :param version_id: The version_id of this ModelVersionOutputV1.
        :type: str
        """
        if version_id is None:
            raise ValueError("Invalid value for `version_id`, must not be `None`")

        self._version_id = version_id

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ModelVersionOutputV1):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
