# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class HierarchyOutputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _alias_column_id: Optional[str]
    _description: Optional[str]
    _effective_permissions: Optional[PermissionsV1]
    _filter_grouping: Optional[str]
    _id: str
    _is_archived: Optional[bool]
    _is_redacted: Optional[bool]
    _name: str
    _scoped_to: Optional[str]
    _status_message: Optional[str]
    _table_definition: ItemPreviewV1
    _table_definition_output: TableDefinitionOutputV1
    _translation_key: Optional[str]
    _type: str
    _view_columns: List[ViewColumnOutputV1]


    def __init__(
        self,
        alias_column_id: Optional[str] = None,
        description: Optional[str] = None,
        effective_permissions: Optional[PermissionsV1] = None,
        filter_grouping: Optional[str] = None,
        id: Optional[str] = None,
        is_archived: Optional[bool] = False,
        is_redacted: Optional[bool] = False,
        name: Optional[str] = None,
        scoped_to: Optional[str] = None,
        status_message: Optional[str] = None,
        table_definition: Optional[ItemPreviewV1] = None,
        table_definition_output: Optional[TableDefinitionOutputV1] = None,
        translation_key: Optional[str] = None,
        type: Optional[str] = None,
        view_columns: Optional[List[ViewColumnOutputV1]] = None,
    ) -> None: ...

    @property
    def alias_column_id(self) -> Optional[str]: ...

    @alias_column_id.setter
    def alias_column_id(self, alias_column_id: Optional[str]) -> None: ...

    @property
    def description(self) -> Optional[str]: ...

    @description.setter
    def description(self, description: Optional[str]) -> None: ...

    @property
    def effective_permissions(self) -> Optional[PermissionsV1]: ...

    @effective_permissions.setter
    def effective_permissions(self, effective_permissions: Optional[PermissionsV1]) -> None: ...

    @property
    def filter_grouping(self) -> Optional[str]: ...

    @filter_grouping.setter
    def filter_grouping(self, filter_grouping: Optional[str]) -> None: ...

    @property
    def id(self) -> str: ...

    @id.setter
    def id(self, id: str) -> None: ...

    @property
    def is_archived(self) -> Optional[bool]: ...

    @is_archived.setter
    def is_archived(self, is_archived: Optional[bool]) -> None: ...

    @property
    def is_redacted(self) -> Optional[bool]: ...

    @is_redacted.setter
    def is_redacted(self, is_redacted: Optional[bool]) -> None: ...

    @property
    def name(self) -> str: ...

    @name.setter
    def name(self, name: str) -> None: ...

    @property
    def scoped_to(self) -> Optional[str]: ...

    @scoped_to.setter
    def scoped_to(self, scoped_to: Optional[str]) -> None: ...

    @property
    def status_message(self) -> Optional[str]: ...

    @status_message.setter
    def status_message(self, status_message: Optional[str]) -> None: ...

    @property
    def table_definition(self) -> ItemPreviewV1: ...

    @table_definition.setter
    def table_definition(self, table_definition: ItemPreviewV1) -> None: ...

    @property
    def table_definition_output(self) -> TableDefinitionOutputV1: ...

    @table_definition_output.setter
    def table_definition_output(self, table_definition_output: TableDefinitionOutputV1) -> None: ...

    @property
    def translation_key(self) -> Optional[str]: ...

    @translation_key.setter
    def translation_key(self, translation_key: Optional[str]) -> None: ...

    @property
    def type(self) -> str: ...

    @type.setter
    def type(self, type: str) -> None: ...

    @property
    def view_columns(self) -> List[ViewColumnOutputV1]: ...

    @view_columns.setter
    def view_columns(self, view_columns: List[ViewColumnOutputV1]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
