# coding: utf-8

"""
    Seeq REST API

    No description provided (generated by Swagger Codegen https://github.com/swagger-api/swagger-codegen)  # noqa: E501

    OpenAPI spec version: 66.120.0-v202603301054-CD
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import annotations

from typing import Any, ClassVar, Dict, List, Optional, Set, TYPE_CHECKING

if TYPE_CHECKING:
    from . import *  # noqa: F401,F403


class AuthInputV1(object):
    swagger_types: ClassVar[Dict[str, str]] = ...
    attribute_map: ClassVar[Dict[str, str]] = ...

    _auth_provider_class: Optional[str]
    _auth_provider_id: Optional[str]
    _code: Optional[str]
    _password: Optional[str]
    _state: Optional[str]
    _username: Optional[str]


    def __init__(
        self,
        auth_provider_class: Optional[str] = None,
        auth_provider_id: Optional[str] = None,
        code: Optional[str] = None,
        password: Optional[str] = None,
        state: Optional[str] = None,
        username: Optional[str] = None,
    ) -> None: ...

    @property
    def auth_provider_class(self) -> Optional[str]: ...

    @auth_provider_class.setter
    def auth_provider_class(self, auth_provider_class: Optional[str]) -> None: ...

    @property
    def auth_provider_id(self) -> Optional[str]: ...

    @auth_provider_id.setter
    def auth_provider_id(self, auth_provider_id: Optional[str]) -> None: ...

    @property
    def code(self) -> Optional[str]: ...

    @code.setter
    def code(self, code: Optional[str]) -> None: ...

    @property
    def password(self) -> Optional[str]: ...

    @password.setter
    def password(self, password: Optional[str]) -> None: ...

    @property
    def state(self) -> Optional[str]: ...

    @state.setter
    def state(self, state: Optional[str]) -> None: ...

    @property
    def username(self) -> Optional[str]: ...

    @username.setter
    def username(self, username: Optional[str]) -> None: ...

    def to_dict(self) -> Dict[str, Any]: ...
    def to_str(self) -> str: ...
    def __repr__(self) -> str: ...
    def __eq__(self, other: object) -> bool: ...
    def __ne__(self, other: object) -> bool: ...
